using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class CMSDesk_Tools_Ecommerce_Orders_Order_List : CMSDeskPage
{
    protected int customerId;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        PageTitle.TitleText = ResHelper.GetString("Order_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Orders/orders.gif";
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Orders/addorder.gif";
        lnkNewItem.Text = ResHelper.GetString("Order_List.NewItemCaption");

        // set filter controls
        lblStatus.Text = ResHelper.GetString("OrderList.StatusLabel");
        lblSites.Text = ResHelper.GetString("OrderList.SitesLabel");
        lblOrderID.Text = ResHelper.GetString("OrderList.OrderIdLabel");
        lblCustomerFirstName.Text = ResHelper.GetString("OrderList.CustomerFirstName");
        lblCustomerLastName.Text = ResHelper.GetString("OrderList.CustomerLastName");

        btnFilter.Text = ResHelper.GetString("General.OK");
        if (!this.IsPostBack)
        {
            drpSites.DataSource = SiteInfoProvider.GetAllSites();
            drpSites.DataBind();
            drpSites.Items.Insert(0, new ListItem(ResHelper.GetString("OrderList.AllSites"), "0"));
        }

        LoadStatus();

        customerId = ValidationHelper.GetInteger(Request.QueryString["customerId"], 0);

        UniGrid.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGrid_OnExternalDataBound);
        UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
        UniGrid.GridView.RowDataBound += new GridViewRowEventHandler(GridView_RowDataBound);
        UniGrid.GridView.GridLines = GridLines.Horizontal;
        if (customerId > 0)
        {
            lnkNewItem.NavigateUrl += "?customerId=" + customerId.ToString();           
            lblCustomerFirstName.Visible = false;
            lblCustomerLastName.Visible = false;
            txtCustomerFirstName.Visible = false;
            txtCustomerLastName.Visible = false;
        }

        LoadData();
    }

    /// <summary>
    /// Fills status dropdownlist
    /// </summary>
    protected void LoadStatus()
    {
        // Remember previously selected item
        ListItem li = drpStatus.SelectedItem;

        drpStatus.DataSource = OrderStatusInfoProvider.GetStatuses(StatusEnum.Both);
        drpStatus.DataBind();
        drpStatus.Items.Insert(0, new ListItem(ResHelper.GetString("OrderList.AllStatus"), "0"));

        if ((li != null) && (drpStatus.Items.FindByValue(li.Value) != null))
        {
            // Mark previously selected item
            drpStatus.SelectedValue = li.Value;
        }

        EcommerceFunctions.MarkEnabledAndDisabledItems(drpStatus, "StatusID", "StatusEnabled");
    }

    void GridView_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            string color = ValidationHelper.GetString(((DataRowView)(e.Row.DataItem)).Row["StatusColor"], "");            
            if (color != "")
            {
                e.Row.Style.Add("background-color", color);
            }
        }
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);
        if (customerId > 0)
        {
            UniGrid.GridView.Columns[2].Visible = false;
            UniGrid.GridView.Columns[3].Visible = false;
        }
    }


    protected void LoadData()
    {
        string where = "";


        // Validate filter form first
        string orderId = txtOrderId.Text.Trim();
        if (orderId != "")
        {
            if ((ValidationHelper.GetInteger(orderId, -1) < 0) || !ValidationHelper.IsPositiveNumber(orderId))
            {
                lblErrorOrderId.Text = ResHelper.GetString("Order_List.WrongFormatOrderID");
                return;
            }
        }


        // status dropdownlist
        if (drpStatus.SelectedIndex > 0)
        {
            where += " OrderStatusID = " + drpStatus.SelectedValue + " AND";
        }
        // site dropdownlist
        if (drpSites.SelectedIndex > 0)
        {
            where += " OrderSiteID = " + drpSites.SelectedValue + " AND";
        }

        if (txtOrderId.Text.Trim() != "")
        {
            where += " OrderID = " + txtOrderId.Text.Trim() + " AND";
        }

        if (customerId > 0)
        {
            where += " CustomerID = " + customerId.ToString() + " AND";
        }
        else
        {
            if (txtCustomerFirstName.Text.Trim() != "")
            {
                where += " CustomerFirstName LIKE '%" + txtCustomerFirstName.Text.Trim() + "%' AND";
            }

            if (txtCustomerLastName.Text.Trim() != "")
            {
                where += " CustomerLastName LIKE '%" + txtCustomerLastName.Text.Trim() + "%' AND";
            }
        }

        if (where != "")
        {
            where = where.Remove(where.Length - 4); // 4 = " AND".Length
        }        

        UniGrid.DataSource = OrderInfoProvider.GetOrderList(where, "OrderDate DESC");
        UniGrid.ReloadData();
    }


    object UniGrid_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        DataRowView dr = null;
        switch (sourceName.ToLower())
        {
            case "fullname":
                dr = (DataRowView)parameter;
                return dr["CustomerFirstName"] + " " + dr["CustomerLastName"];

            case "totalprice":
                dr = (DataRowView)parameter;
                return String.Format(dr["CurrencyFormatString"].ToString(), dr["OrderTotalPrice"]);

            case "statusdisplayname":
                return ResHelper.LocalizeString(Convert.ToString(parameter));
                //break;
        }
        return parameter;
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void uniGrid_OnAction(string actionName, object actionArgument)
    {
        int orderId = ValidationHelper.GetInteger(actionArgument, 0);
        OrderInfo oi = null;
        OrderStatusInfo osi = null;

        switch (actionName.ToLower())
        {
            case "edit":        
                string redirectToUrl = "Order_Edit.aspx?orderID=" + orderId.ToString();
                if (customerId > 0)
                {
                    redirectToUrl += "&customerId=" + customerId.ToString();
                }
                Response.Redirect(redirectToUrl);
            break;
        

            case "delete":        
                // check 'EcommerceModify' permission
                if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
                {
                    CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
                }

                // delete OrderInfo object from database
                OrderInfoProvider.DeleteOrderInfo(orderId);
                LoadData();
                break;

            case "previous":
                oi = OrderInfoProvider.GetOrderInfo(orderId);
                if (oi != null)
                {
                    osi = OrderStatusInfoProvider.GetPreviousEnabledStatus(oi.OrderStatusID);
                    if (osi != null)
                    {
                        oi.OrderStatusID = osi.StatusID;
                        // Save order status changes
                        OrderInfoProvider.SetOrderInfo(oi);
                        // Save order history
                        SaveOrderDataToHistory(oi.OrderStatusID, osi.StatusID, oi.OrderID);
                        LoadData();
                    }
                }   
                break;

            case "next":
                oi = OrderInfoProvider.GetOrderInfo(orderId);
                if (oi != null)
                {
                    osi = OrderStatusInfoProvider.GetNextEnabledStatus(oi.OrderStatusID);
                    if (osi != null)
                    {
                        oi.OrderStatusID = osi.StatusID;
                        // Save order status changes
                        OrderInfoProvider.SetOrderInfo(oi);
                        // Save order history
                        SaveOrderDataToHistory(oi.OrderStatusID, osi.StatusID, oi.OrderID);
                        LoadData();
                    }
                }
                break;

        }
    }

    /// <summary>
    /// Saves order info to history
    /// </summary>
    /// <param name="fromStatuId">From status ID.</param>
    /// <param name="toStatusId">To status ID.</param>
    /// <param name="orderId">Order ID.</param>
    private void SaveOrderDataToHistory(int fromStatusId, int toStatusId, int orderId)
    {
        OrderStatusUserInfo orderStatusUser = new OrderStatusUserInfo();
        orderStatusUser.ChangedByUserID = CMSContext.CurrentUser.UserID;
        orderStatusUser.Date = DateTime.Now;
        orderStatusUser.FromStatusID = fromStatusId;
        orderStatusUser.Note = "";
        orderStatusUser.OrderID = orderId;
        orderStatusUser.ToStatusID = toStatusId;
        OrderStatusUserInfoProvider.SetOrderStatusUserInfo(orderStatusUser);
    }


    protected void btnFilter_Clicked(object sender, EventArgs e)
    {
        LoadData();
    }
}
