using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.DataEngine;
using CMS.CMSHelper;
using CMS.Ecommerce;

public partial class CMSDesk_Tools_Ecommerce_Products_Product_List : CMSDeskPage
{
    //string reportFields = "SKUName;SKUNumber;SKUPrice;";
    protected string editToolTip = ResHelper.GetString("Product_List.EditToolTip");
    protected string deleteToolTip = ResHelper.GetString("Product_List.DeleteToolTip");

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        lblStoreStatus.Text = ResHelper.GetString("Product_List.StoreStatus");
        lblInternalStatus.Text = ResHelper.GetString("Product_List.InternalStatus");
        lblDepartment.Text = ResHelper.GetString("Product_List.Department");
        lblName.Text = ResHelper.GetString("Product_List.Name");
        lblNumber.Text = ResHelper.GetString("Product_List.Number");
        btnFilter.Text = ResHelper.GetString("Product_List.Filter");

        lnkNewItem.Text = ResHelper.GetString("Product_List.NewItem");
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Products/addproduct.gif";

        ProductsPageTitle.TitleText = ResHelper.GetString("Product_List.HeaderCaption");
        ProductsPageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Products/products.gif";
       
        gridData.OnAction += new OnActionEventHandler(gridData_OnAction);
        gridData.OnExternalDataBound += new OnExternalDataBoundEventHandler(gridData_OnExternalDataBound);

        if (CMSContext.CurrentUser != null)
        {

            if (!IsPostBack)
            {

                // fill department dropdownlist

                if (CMSContext.CurrentUser.IsGlobalAdministrator)
                {
                    drpDepartment.DataSource = DepartmentInfoProvider.GetDepartments();
                }
                else
                {
                    drpDepartment.DataSource = DepartmentInfoProvider.GetUserDepartments(CMSContext.CurrentUser.UserID);
                }
                drpDepartment.DataBind();
                drpDepartment.Items.Insert(0, new ListItem(ResHelper.GetString("Product_List.AllMyDepartments"), ""));

                drpInternalStatus.DataSource = InternalStatusInfoProvider.GetStatuses(StatusEnum.Both);
                drpInternalStatus.DataBind();
                drpInternalStatus.Items.Insert(0, new ListItem(ResHelper.GetString("Product_List.AllInternalStatus"), ""));

                drpStoreStatus.DataSource = PublicStatusInfoProvider.GetStatuses(StatusEnum.Both);
                drpStoreStatus.DataBind();
                drpStoreStatus.Items.Insert(0, new ListItem(ResHelper.GetString("Product_List.AllStoreStatus"), ""));
            }

            LoadData();
        }        
    }


    object gridData_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        if (sourceName.ToLower() == "publicstatusdisplayname")
        {
            return ResHelper.LocalizeString(Convert.ToString(parameter));
        }
        return parameter;
    }


    void gridData_OnAction(string actionName, object actionArgument)
    {
        switch (actionName.ToLower())
        {
            case "edit":
                Response.Redirect("Product_Edit_Frameset.aspx?productid=" + ValidationHelper.GetInteger(actionArgument, 0));
                break;

            case "delete":

                // check 'EcommerceModify' permission
                if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
                {
                    CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
                }

                // Check dependencies
                if (SKUInfoProvider.CheckDependencies(ValidationHelper.GetInteger(actionArgument, 0)))
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Ecommerce.DeleteDisabled");
                    return;
                }

                SKUInfoProvider.DeleteSKUInfo(ValidationHelper.GetInteger(actionArgument, 0));
                LoadData();
            
                break;
        }
    }


    protected void btnFilter_Click(object sender, EventArgs e)
    {
        LoadData();       
    }

    /// <summary>
    /// Reloads Unigrid data
    /// </summary>
    protected void LoadData()
    {
        string where = "";
        // value from txtName
        if (txtName.Text != "")
        {
            where += "SKUName LIKE '%" + txtName.Text.Trim() + "%' AND ";
        }
        // value from txtNumber
        if (txtNumber.Text != "")
        {
            where += "SKUNumber LIKE '%" + txtNumber.Text.Trim() + "%' AND ";
        }
        // value from drpDepartment
        if (drpDepartment.SelectedIndex != 0)
        {
            where += "SKUDepartmentID=" + drpDepartment.SelectedValue + " AND ";
        }
        // Internal status value
        if (drpInternalStatus.SelectedIndex != 0)
        {
            where += "InternalStatusID = " + drpInternalStatus.SelectedValue + " AND ";
        }
        // Store status value
        if (drpStoreStatus.SelectedIndex != 0)
        {
            where += "PublicStatusID = " + drpStoreStatus.SelectedValue + " AND ";
        }


        if (CMSContext.CurrentUser != null)
        {
            if (CMSContext.CurrentUser.IsGlobalAdministrator)
            {
                // display products from all departments to Global administrator
                if (where != "")
                {
                    // trim ending ' AND'
                    where = where.Remove(where.Length - 4);
                }
            }
            else
            {
                // Complete where
                where += "SKUDepartmentID IN (SELECT DepartmentID FROM COM_UserDepartment WHERE UserID=" + CMSContext.CurrentUser.UserID + ")";
            }

            gridData.DataSource = SKUInfoProvider.GetSKUList(where, "SKUName");
            gridData.ReloadData();
        }

        if (DataHelper.DataSourceIsEmpty(gridData.DataSource))
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("Product_List.NoProductAvailable");
        }

    }
}
