using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Xml;
using System.Text;

using CMS.Newsletter;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Controls;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Newsletters_Newsletters_Newsletter_Iframe_Edit : CMSDeskPage
{

    private int mIssueID = 0;
    private int mNewsletterID = 0;
    private int templateId = 0;
    private ArrayList regionList = new ArrayList();
    private Hashtable regionsContents = new Hashtable();
    Issue issue = null;

    
    protected void Page_Load(object sender, EventArgs e)
    {

        lblSubject.Text = ResHelper.GetString("NewsletterTemplate_Edit.Subject");

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "Reload", ScriptHelper.GetScript("" +
           "function SaveContent(callNext){" +
           " if (callNext) { document.getElementById('" + this.hdnNext.ClientID + "').value = 1; } " +
           this.Page.ClientScript.GetPostBackEventReference(btnHidden, null) +
           "}"));

        mIssueID = ValidationHelper.GetInteger(Request.QueryString["IssueID"], 0);
        if (mIssueID == 0)
        {
            mIssueID = ValidationHelper.GetInteger(hdnIssueId.Value, 0);
        }

        mNewsletterID = ValidationHelper.GetInteger(Request.QueryString["NewsletterId"], 0);

        if (mIssueID > 0)
        {
            issue = IssueProvider.GetIssue(mIssueID);
            if (issue != null)
            {
                templateId = issue.IssueTemplateID;
            }
        }
        else if (mNewsletterID > 0)
        {
            Newsletter newsletter = NewsletterProvider.GetNewsletter(mNewsletterID);
            if (newsletter != null)
            {
                templateId = newsletter.NewsletterTemplateID;
            }
        }


        if (templateId > 0)
        {
            LoadContent();
        }

        if (!IsPostBack)
        {
            if ((issue != null))
            {
                txtSubject.Text = issue.IssueSubject;
            }
        }

        LoadRegionList();

    }


    private void LoadContent()
    {
        EmailTemplate emailTemplate = EmailTemplateProvider.GetEmailTemplate(templateId);
        if (emailTemplate == null)
        {
            return;
        }
        string templateText = emailTemplate.TemplateBody;
        LiteralControl before = new LiteralControl();
        CMSEditableRegion editableRegion = new CMSEditableRegion();
        editableRegion.ViewMode = ViewModeEnum.Edit;

        if (!IsPostBack && (issue != null))
        {
            LoadRegionsContents();
        }

        int count = 0;
        int textStart = 0;
        int editRegStart = templateText.IndexOf("$$", textStart);

        while (editRegStart >= 0)
        {
            count++;

            before = new LiteralControl();
            before.Text = UrlHelper.MakeLinksAbsolute(templateText.Substring(textStart, (editRegStart - textStart)));
            plcContent.Controls.Add(before);

            // End of region
            editRegStart += 2;
            textStart = editRegStart;
            if (editRegStart < templateText.Length - 1)
            {
                int editRegEnd = templateText.IndexOf("$$", editRegStart);
                if (editRegEnd >= 0)
                {
                    string region = templateText.Substring(editRegStart, editRegEnd - editRegStart);
                    string[] parts = (region + ":" + ":").Split(':');

                    try
                    {
                        string name = parts[0];
                        if (name.Trim() != "")
                        {

                            int width = ValidationHelper.GetInteger(parts[1], 0);
                            int height = ValidationHelper.GetInteger(parts[2], 0);

                            editableRegion = new CMSEditableRegion();
                            editableRegion.ID = name;
                            editableRegion.RegionType = CMSEditableRegionTypeEnum.HtmlEditor;
                            editableRegion.ViewMode = ViewModeEnum.Edit;

                            editableRegion.DialogHeight = height;
                            editableRegion.DialogWidth = width;

                            editableRegion.WordWrap = false;
                            editableRegion.HtmlAreaToolbarLocation = "Out:parent(FCKEditorToolbar)";
                            editableRegion.RegionTitle = name;
                            editableRegion.UseStylesheet = false;
                            editableRegion.HTMLEditorCssStylesheet = EmailTemplateProvider.GetStylesheetUrl(emailTemplate.TemplateName);
                            editableRegion.HtmlAreaToolbar = "Newsletter";

                            editableRegion.LoadContent(ValidationHelper.GetString(regionsContents[name.ToLower()], ""));

                            plcContent.Controls.Add(editableRegion);

                            textStart = editRegEnd + 2;
                        }
                    }
                    catch
                    {
                    }
                }
            }
            editRegStart = templateText.IndexOf("$$", textStart);
        }

        before = new LiteralControl();
        before.Text = UrlHelper.MakeLinksAbsolute(templateText.Substring(textStart));

        plcContent.Controls.Add(before);
    }


    protected void LoadRegionsContents()
    {
        regionsContents.Clear();
        string contentXml = issue.IssueText;
        if (contentXml != "")
        {
            XmlDocument xml = new XmlDocument();
            xml.LoadXml(contentXml);
            XmlNode docElem = xml.DocumentElement;

            // Load editable regions
            XmlNodeList regions = docElem.SelectNodes("region");
            if (regions != null)
            {
                foreach (XmlNode region in regions)
                {
                    string id = region.Attributes["id"].Value;
                    string value = region.InnerText;
                    regionsContents[id.ToLower()] = value;
                }
            }
        }
    }


    /// <summary>
    /// Saves the content to the specified Issue
    /// </summary>
    /// <param name="issue">Issue data</param>
    public string SaveContent(Issue issue)
    {
        CMSEditableRegion editReg;
        XmlWriterSettings settings = new XmlWriterSettings();
        settings.Indent = true;
        settings.NewLineOnAttributes = false;
        //string xmlOutput = "";
        StringBuilder sb = new StringBuilder();
        using (XmlWriter writer = XmlWriter.Create(sb, settings))
        {
            writer.WriteStartDocument();
            writer.WriteStartElement("content");

            for (int i = 0; i < regionList.Count; i++)
            {
                editReg = (CMSEditableRegion)regionList[i];
                writer.WriteStartElement("region");
                writer.WriteStartAttribute("id");
                writer.WriteValue(editReg.ID);
                writer.WriteEndAttribute();
                writer.WriteString(editReg.GetContent());
                //writer.WriteString(editReg.content);
                writer.WriteEndElement(); //region
            }

            writer.WriteEndElement(); //content
            writer.WriteEndDocument();
        }

        issue.IssueText = sb.ToString();
        return "";

    }


    protected void LoadRegionList()
    {
        regionList = CMSPageManager.CollectEditableControls(plcContent);

        //create array of regions IDs in javascript. We will use it to find out the focused region
        string script = "var focusedRegionID = ''; \n var regions = new Array(" + regionList.Count.ToString() + "); \n ";
        for (int i = 0; i < regionList.Count; i++)
        {
            script += "regions[" + i.ToString() + "] = '" + ((CMSEditableRegion)regionList[i]).ClientID + "_fckValue'; \n ";
        }
        ltlScript.Text = ScriptHelper.GetScript(script);
    }


    /// <summary>
    /// Save click handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnHidden_Click(object sender, EventArgs e)
    {
        string result = new Validator().NotEmpty(txtSubject.Text, ResHelper.GetString("NewsletterContentEditor.SubjectRequired")).Result;

        if (result == "")
        {
            if (this.issue == null)
            {
                this.issue = new Issue();
                this.issue.IssueUnsubscribed = 0;
                this.issue.IssueSentEmails = 0;
                this.issue.IssueTemplateID = templateId;
                this.issue.IssueNewsletterID = mNewsletterID;
            }

            SaveContent(issue);
            issue.IssueSubject = txtSubject.Text.Trim();
            IssueProvider.SetIssue(issue);

            hdnIssueId.Value = issue.IssueID.ToString();

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");


            if (hdnNext.Value == "1")
            {
                ltlScript2.Text = ScriptHelper.GetScript("parent.NextClick('"+issue.IssueID.ToString()+"');");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }
}
