using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_General : CMSDeskPage
{
    protected int pollId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        // Required field validator error messages initialization
        rfvCodeName.ErrorMessage = ResHelper.GetString("Polls_New.CodeNameError");
        rfvDisplayName.ErrorMessage = ResHelper.GetString("Polls_New.DisplayNameError");
        rfvQuestion.ErrorMessage = ResHelper.GetString("Polls_New.QuestionError");

        // Control initializations
        lblDisplayName.Text = ResHelper.GetString("Polls_Edit.PollDisplayNameLabel");
        lblCodeName.Text = ResHelper.GetString("Polls_Edit.PollCodeNameLabel");
        lblTitle.Text = ResHelper.GetString("Polls_Edit.PollTitleLabel");
        lblQuestion.Text = ResHelper.GetString("Polls_Edit.PollQuestionLabel");
        lblOpenFrom.Text = ResHelper.GetString("Polls_Edit.PollOpenFromLabel");
        lblOpenTo.Text = ResHelper.GetString("Polls_Edit.PollOpenToLabel");
        lblResponseMessage.Text = ResHelper.GetString("Polls_Edit.PollResponseMessageLabel");
        lblAllowMultipleAnswers.Text = ResHelper.GetString("Polls_Edit.PollAllowMultipleAnswersLabel");

        btnOK.Text = ResHelper.GetString("General.OK");
        dtPickerOpenFrom.SupportFolder = "~/CMSAdminControls/Calendar";
        dtPickerOpenTo.SupportFolder = "~/CMSAdminControls/Calendar";

        string currentPoll = null;
        // Get poll id from querystring		
        pollId = ValidationHelper.GetInteger(Request.QueryString["pollId"], 0);
        PollInfo pollObj = PollInfoProvider.GetPollInfo(pollId);
        if (pollObj != null)
        {
            currentPoll = pollObj.PollDisplayName;

            // Fill editing form
            if (!IsPostBack)
            {
                LoadData(pollObj);

                // Show that the poll was created or updated successfully
                if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }
    }


    /// <summary>
    /// Load data of editing poll.
    /// </summary>
    /// <param name="pollObj">Poll object.</param>
    protected void LoadData(PollInfo pollObj)
    {
        // Load the fields
        txtCodeName.Text = pollObj.PollCodeName;
        txtDisplayName.Text = pollObj.PollDisplayName;
        txtTitle.Text = pollObj.PollTitle;
        txtQuestion.Text = pollObj.PollQuestion;
        if (pollObj.PollOpenFrom != DataHelper.DATETIME_NOT_SELECTED)
        {
            dtPickerOpenFrom.SelectedDateTime = pollObj.PollOpenFrom;
        }
        if (pollObj.PollOpenTo != DataHelper.DATETIME_NOT_SELECTED)
        {
            dtPickerOpenTo.SelectedDateTime = pollObj.PollOpenTo;
        }
        txtResponseMessage.Text = pollObj.PollResponseMessage;
        chkAllowMultipleAnswers.Checked = pollObj.PollAllowMultipleAnswers;
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        // Validate the fields
        string errorMessage = new Validator().NotEmpty(txtCodeName.Text, rfvCodeName.ErrorMessage)
            .NotEmpty(txtDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtQuestion.Text, rfvQuestion.ErrorMessage).Result;

        if (!ValidationHelper.IsCodeName(txtCodeName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }
        else
        {
            // from/to date validation
            if (errorMessage == "")
            {
                if ((dtPickerOpenFrom.SelectedDateTime != DateTime.MinValue) &&
                (dtPickerOpenTo.SelectedDateTime != DateTime.MinValue) &&
                (dtPickerOpenFrom.SelectedDateTime >= dtPickerOpenTo.SelectedDateTime))
                {
                    errorMessage = ResHelper.GetString("General.DateOverlaps");
                }
            }
        }

        if (errorMessage == "")
        {
            // Check uniqeness
            PollInfo pollObj = PollInfoProvider.GetPollInfo(txtCodeName.Text);
            if ((pollObj == null) || (pollObj.PollID == pollId))
            {
                pollObj = PollInfoProvider.GetPollInfo(pollId);
                if (pollObj != null)
                {
                    // Store the fields
                    pollObj.PollCodeName = txtCodeName.Text.Trim();
                    pollObj.PollDisplayName = txtDisplayName.Text.Trim();
                    pollObj.PollTitle = txtTitle.Text.Trim();
                    pollObj.PollQuestion = txtQuestion.Text.Trim();
                    pollObj.PollOpenFrom = dtPickerOpenFrom.SelectedDateTime;
                    pollObj.PollOpenTo = dtPickerOpenTo.SelectedDateTime;
                    pollObj.PollResponseMessage = txtResponseMessage.Text.Trim();
                    pollObj.PollAllowMultipleAnswers = chkAllowMultipleAnswers.Checked;

                    // Save the data
                    PollInfoProvider.SetPollInfo(pollObj);

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                else
                {
                    // Error message - Poll does not exist
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("polls.pollnotexist");
                }
            }
            else
            {
                // Error message - Code name already exist
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("polls.codenameexists");
            }
        }
        else
        {
            // Error message - validation
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
