using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_Sites : CMSDeskPage
{
    /// <summary>
    /// Poll ID
    /// </summary>
    protected int pollId = 0;


    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        pollId = ValidationHelper.GetInteger(Request.QueryString["pollId"], 0);

        if (pollId > 0)
        {
            // Control initialization
            btnOK.Text = ResHelper.GetString("General.OK");
            GridViewSites.Columns[1].HeaderText = ResHelper.GetString("Polls_Sites.Site");
            DataSet ds = SiteInfoProvider.GetAllSites();
            GridViewSites.Columns[2].Visible = true;
            GridViewSites.DataSource = ds.Tables[0];
            GridViewSites.DataBind();
            // After id is copied, the 3rd column is not needed anymore
            GridViewSites.Columns[2].Visible = false;
            GridViewSites.GridLines = GridLines.Horizontal;
        }
    }


    /// <summary>
    /// On databound event handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void GridViewSites_DataBound(object sender, EventArgs e)
    {
        DataSet ds = PollInfoProvider.GetPollSites(pollId);

        for (int i = 0; i < GridViewSites.Rows.Count; i++)
        {
            CheckBox isMember = new CheckBox();

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(ValidationHelper.GetInteger(GridViewSites.Rows[i].Cells[2].Text, 0));
                if (si != null)
                {
                    DataRow[] rows = ds.Tables[0].Select("SiteName='" + si.SiteName + "'");
                    if (rows.Length > 0)
                    {
                        isMember.Checked = true;
                    }
                }
            }
            GridViewSites.Rows[i].Cells[0].Controls.Add(isMember);

            Label id = new Label();
            // Copy id from 3rd column to invisible label in first column
            id.Text = GridViewSites.Rows[i].Cells[2].Text;
            id.Attributes.Add("style", "display: none;");
            GridViewSites.Rows[i].Cells[0].Controls.Add(id);
        }
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        for (int i = 0; i < GridViewSites.Rows.Count; i++)
        {
            CheckBox isMember = (CheckBox)GridViewSites.Rows[i].Cells[0].Controls[0];
            Label lblId = (Label)GridViewSites.Rows[i].Cells[0].Controls[1];

            // Check the existence of the site
            SiteInfo si = SiteInfoProvider.GetSiteInfo(ValidationHelper.GetInteger(lblId.Text, 0));
            if (si != null)
            {
                if (isMember.Checked)
                {
                    // If poll is not in site, add it to the site
                    PollInfoProvider.AddPollToSite(pollId, si.SiteID);
                }
                else
                {
                    // If poll is in site, remove it from the site
                    PollInfoProvider.RemovePollFromSite(pollId, si.SiteID);
                }
            }
            else
            {
                return;
            }
        }

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }
}
