using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class CMSEcommerce_MyDetails : UserControl
{
    private CustomerInfo mCustomer = null;

    /// <summary>
    /// Customer info object.
    /// </summary>
    public CustomerInfo Customer
    {
        get { return mCustomer; }
        set { mCustomer = value; }
    }
    

    /// <summary>
    /// If true, control does not process the data
    /// </summary>
    public bool StopProcessing
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["StopProcessing"], false);
        }
        set
        {
            ViewState["StopProcessing"] = value;
            this.drpCountry.StopProcessing = value;
            this.drpCurrency.StopProcessing = value;
            this.drpPayment.StopProcessing = value;
            this.drpShipping.StopProcessing = value;
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!StopProcessing)
        {
            btnOK.Text = ResHelper.GetString("General.OK");
            lblCustomerLastName.Text = ResHelper.GetString("Customers_Edit.CustomerLastNameLabel");
            lblCustomerFirstName.Text = ResHelper.GetString("Customers_Edit.CustomerFirstNameLabel");
            lblCustomerCompany.Text = ResHelper.GetString("Customers_Edit.CustomerCompanyLabel");
            lblCustomerFax.Text = ResHelper.GetString("customers_edit.CustomerFax");
            lblCustomerPhone.Text = ResHelper.GetString("customers_edit.CustomerPhone");
            lblCustomerPreferredCurrency.Text = ResHelper.GetString("customers_edit.CustomerCurrency");
            lblCustomerPreferredShippingOption.Text = ResHelper.GetString("customers_edit.CustomerShipping");
            lblCustomerPrefferedPaymentOption.Text = ResHelper.GetString("customers_edit.CustomerPayment");
            lblCustomerEmail.Text = ResHelper.GetString("customers_edit.CustomerEmail");
            lblCustomerCountry.Text = ResHelper.GetString("Customers_Edit.CustomerCountry");
            if (CMSContext.CurrentSite.SiteShowTaxRegistrationID)
            {
                lblTaxRegistrationID.Text = ResHelper.GetString("Customers_Edit.lblTaxRegistrationID");
            }
            else
            {
                plhTaxRegistrationID.Visible = false;
            }
            if (CMSContext.CurrentSite.SiteShowOrganizationID)
            {
                lblOrganizationID.Text = ResHelper.GetString("Customers_Edit.lblOrganizationID");
            }
            else
            {
                plhOrganizationID.Visible = false;
            }

            if (mCustomer != null)
            {
                // Fill editing form
                if (!IsPostBack)
                {
                    LoadData();

                    // Show that the customer was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }
            else
            {
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("MyAccount.MyDetails.CreateNewCustomer");
            }
        }
    }


    /// <summary>
    /// Load form data.
    /// </summary>
    public void LoadData()
    {
        txtCustomerCompany.Text = mCustomer.CustomerCompany;
        txtCustomerEmail.Text = mCustomer.CustomerEmail;
        txtCustomerFax.Text = mCustomer.CustomerFax;
        txtCustomerFirstName.Text = mCustomer.CustomerFirstName;
        txtCustomerLastName.Text = mCustomer.CustomerLastName;
        txtCustomerPhone.Text = mCustomer.CustomerPhone;
        txtOraganizationID.Text = mCustomer.CustomerOrganizationID;
        txtTaxRegistrationID.Text = mCustomer.CustomerTaxRegistrationID;

        if (mCustomer.CustomerCountryID > 0)
        {
            drpCountry.CountryID = mCustomer.CustomerCountryID;
        }
        if (mCustomer.CustomerStateID > 0)
        {
            drpCountry.StateID = mCustomer.CustomerStateID;
        }
        if (mCustomer.CustomerPreferredCurrencyID > 0)
        {
            drpCurrency.CurrencyID = mCustomer.CustomerPreferredCurrencyID;
        }
        if (mCustomer.CustomerPrefferedPaymentOptionID > 0)
        {
            drpPayment.PaymentID = mCustomer.CustomerPrefferedPaymentOptionID;
        }
        if (mCustomer.CustomerPreferredShippingOptionID > 0)
        {
            drpShipping.ShippingID = mCustomer.CustomerPreferredShippingOptionID;
        }
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        string errorMessage = "";

        if ((txtCustomerCompany.Text == null || txtCustomerCompany.Text.Trim() == "") &&
            ((txtCustomerFirstName.Text == null || txtCustomerFirstName.Text.Trim() == "") ||
             (txtCustomerLastName.Text == null || txtCustomerLastName.Text.Trim() == "")))
        {
            errorMessage = ResHelper.GetString("Customers_Edit.errorInsert");
        }

        if (errorMessage == "")
        {
            errorMessage = new Validator().IsEmail(txtCustomerEmail.Text.Trim(), ResHelper.GetString("customers_edit.erroremailformat")).Result;
        }

        if (errorMessage == "")
        {
            // Check if user exists             
            UserInfo ui = UserInfoProvider.GetUserInfo(txtCustomerEmail.Text.Trim());
            if ((ui != null) && (ui.UserID != CMSContext.CurrentUser.UserID))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ShoppingCartUserRegistration.ErrorUserExists");
                return;
            }

            // If customer doesn't already exist, create new one
            if (mCustomer == null)
            {
                mCustomer = new CustomerInfo();
                mCustomer.CustomerEnabled = true;
                mCustomer.CustomerUserID = CMSContext.CurrentUser.UserID;
            }

            mCustomer.CustomerPreferredCurrencyID = drpCurrency.CurrencyID;
            mCustomer.CustomerEmail = txtCustomerEmail.Text.Trim();
            mCustomer.CustomerPrefferedPaymentOptionID = drpPayment.PaymentID;
            mCustomer.CustomerFax = txtCustomerFax.Text.Trim();
            mCustomer.CustomerPreferredShippingOptionID = drpShipping.ShippingID;
            mCustomer.CustomerLastName = txtCustomerLastName.Text.Trim();
            mCustomer.CustomerPhone = txtCustomerPhone.Text.Trim();
            mCustomer.CustomerFirstName = txtCustomerFirstName.Text.Trim();
            mCustomer.CustomerCompany = txtCustomerCompany.Text.Trim();
            mCustomer.CustomerCountryID = drpCountry.CountryID;
            mCustomer.CustomerStateID = drpCountry.StateID;
            if (CMSContext.CurrentSite.SiteShowOrganizationID)
            {
                mCustomer.CustomerOrganizationID = txtOraganizationID.Text.Trim();
            }
            if (CMSContext.CurrentSite.SiteShowTaxRegistrationID)
            {
                mCustomer.CustomerTaxRegistrationID = txtTaxRegistrationID.Text.Trim();
            }

            CustomerInfoProvider.SetCustomerInfo(mCustomer);

            Response.Redirect(UrlHelper.AddParameterToUrl(Request.RawUrl, "saved", "1"));
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}