using System.Xml;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System;
using System.Collections;
using System.Configuration;
using System.Drawing;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.Security;
using System.Web.Configuration;
using System.Security;
using System.Security.AccessControl;
using System.Security.Principal;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.LicenseProvider;
using CMS.ImportExport;
using CMS.TreeEngine;
using CMS.SettingsProvider;
using CMS.DirectoryUtilities;
using CMS.IDataConnectionLibrary;

public partial class CMSDeskInstall : Page
{
    private string hostName = HttpContext.Current.Request.Url.Host.ToLower();
    private string fullHostName = HttpContext.Current.Request.Url.Host.ToLower() + (HttpContext.Current.Request.Url.IsDefaultPort ? "" : ":" + HttpContext.Current.Request.Url.Port);

    /// <summary>
    /// import settings stored in cache
    /// </summary>
    public SQLServerAuthenticationModeEnum authenticationType
    {
        get
        {
            if (ViewState["authentication"] == null)
            {
                if (IsPostBack)
                {
                    throw new Exception("Connection information was lost!");
                }
            }
            return (SQLServerAuthenticationModeEnum)ViewState["authentication"];
        }
        set
        {
            ViewState["authentication"] = value;
        }
    }


    /// <summary>
    /// New site domain
    /// </summary>
    public string Domain
    {
        get
        {
            if (ViewState["newsitedomain"] == null)
            {
                ViewState["newsitedomain"] = "";
            }
            return (string)ViewState["newsitedomain"];
        }

        set
        {
            ViewState["newsitedomain"] = value;
        }
    }


    /// <summary>
    /// Connection string
    /// </summary>
    public string ConnectionString
    {
        get
        {
            if (ViewState["connString"] == null)
            {
                ViewState["connString"] = "";
            }
            return (string)ViewState["connString"];
        }

        set
        {
            ViewState["connString"] = value;
        }
    }


    /// <summary>
    /// Step index
    /// </summary>
    public int StepIndex
    {
        get
        {
            if (ViewState["stepIndex"] == null)
            {
                ViewState["stepIndex"] = 1;
            }
            return (int)ViewState["stepIndex"];
        }

        set
        {
            ViewState["stepIndex"] = value;
        }
    }


    private string mResult
    {
        get
        {
            if (ViewState["result"] == null)
            {
                if (IsPostBack)
                {
                    throw new Exception("Information was lost!");
                }
            }
            return (string)ViewState["result"];
        }
        set
        {
            ViewState["result"] = value;
        }
    }


    private bool mDisplayLog
    {
        get
        {
            if (ViewState["displLog"] == null)
            {
                if (IsPostBack)
                {
                    throw new Exception("Information was lost!");
                }
                return false;
            }
            return (bool)ViewState["displLog"];
        }
        set
        {
            ViewState["displLog"] = value;
        }
    }

    protected void Page_Load(System.Object sender, System.EventArgs e)
    {
        Response.Cache.SetNoStore();

        btnPermissionTest.Click += new EventHandler(btnPermissionTest_Click);
        btnPermissionSkip.Click += new EventHandler(btnPermissionSkip_Click);
        btnPermissionContinue.Click += new EventHandler(btnPermissionContinue_Click);

        // If the connection string is set, redirect
        if (!this.IsPostBack)
        {
            if ((ConfigurationManager.ConnectionStrings["CMSConnectionString"] != null) && (ConfigurationManager.ConnectionStrings["CMSConnectionString"].ConnectionString != ""))
            {
                Response.Redirect("~/default.aspx");
            }


            bool checkPermission = Convert.ToBoolean(ValidationHelper.GetInteger(Request.QueryString["checkpermission"], 1));
            bool testAgain = Convert.ToBoolean(ValidationHelper.GetInteger(Request.QueryString["testagain"], 0));

            string dir = HttpContext.Current.Server.MapPath("~/");
            if (!DirectoryHelper.CheckPermissions(dir, false, true, true, true) && checkPermission)
            {

                pnlWizard.Visible = false;
                pnlPermission.Visible = true;
                pnlButtons.Visible = true;

                lblPermission.Text = string.Format(ResHelper.GetFileString("Install.lblPermission"), System.Security.Principal.WindowsIdentity.GetCurrent().Name, dir);
                btnPermissionSkip.Text = ResHelper.GetFileString("Install.btnPermissionSkip");
                btnPermissionTest.Text = ResHelper.GetFileString("Install.btnPermissionTest");

                // Show troubleshoot link
                this.lnkTroubleshoot.Visible = true;
                this.lnkTroubleshoot.Target = "_blank";
                this.lnkTroubleshoot.Text = ResHelper.GetFileString("Install.ErrorPermissions");
                this.lnkTroubleshoot.NavigateUrl = ResolveUrl("~/CMSMessages/DiskPermissions.aspx");
                return;
            }

            if (testAgain)
            {
                pnlWizard.Visible = false;
                pnlPermission.Visible = false;
                pnlButtons.Visible = false;
                pnlPermissionSuccess.Visible = true;
                lblPermissionSuccess.Text = ResHelper.GetFileString("Install.lblPermissionSuccess");
                btnPermissionContinue.Text = ResHelper.GetFileString("Install.btnPermissionContinue");
                return;
            }

        }

        pnlWizard.Visible = true;
        pnlPermission.Visible = false;
        pnlButtons.Visible = false;

        if (!this.IsPostBack)
        {
            if (HttpContext.Current != null)
            {
                txtServerName.Text = HttpContext.Current.Server.MachineName;
            }
            authenticationType = SQLServerAuthenticationModeEnum.SQLServerAuthentication;
            string webDirectory = CMSContext.WebApplicationVirtualPath.Replace("/", "");
            if ((webDirectory == "") || (webDirectory == "~"))
            {
                webDirectory = "KenticoCMS";
            }
            this.txtNewDatabaseName.Text = webDirectory;

            wzdInstaller.ActiveStepIndex = 0;
            this.lblHeader.Text = string.Format(ResHelper.GetFileString("Install.DBHeaderStep"), StepIndex);
        }
        else
        {
            if (ViewState["install.password"] == null)
                ViewState["install.password"] = this.txtPassword.Text.Trim();
        }

        // Load the strings
        this.mDisplayLog = false;
        this.lblError.Text = "";
        this.lnkTroubleshoot.Visible = false;

        this.lblExistingDatabaseName.Text = ResHelper.GetFileString("Install.lblExistingDatabaseName");
        this.lblCreateDatabaseObjects.Text = ResHelper.GetFileString("Install.chkCreateDatabaseObjects");
        this.lblPassword.Text = ResHelper.GetFileString("Install.lblPassword");
        this.lblUsername.Text = ResHelper.GetFileString("Install.lblUsername");
        this.lblServerName.Text = ResHelper.GetFileString("Install.lblServername");
        this.lblCompleted.Text = ResHelper.GetFileString("Install.DBSetupOK");
        this.lblLog.Text = ResHelper.GetFileString("Install.lblLog");
        //this.lblWebSite.Text = ResHelper.GetFileString("Install.lblWebSite");
        this.radCreateNew.Text = ResHelper.GetFileString("Install.radCreateNew");
        this.radUseExisting.Text = ResHelper.GetFileString("Install.radUseExisting");
        this.lblNewDatabaseName.Text = ResHelper.GetFileString("Install.lblNewDatabaseName");
        this.lblSiteCreationInfo.Text = ResHelper.GetFileString("Install.lblSiteCreationInfo");
        this.lblMediumTrustInfo.Text = ResHelper.GetFileString("Install.MediumTrustInfo");

        this.radSQLAuthentication.Text = ResHelper.GetFileString("Install.radSQlAuthentication");
        this.radWindowsAuthentication.Text = String.Format(ResHelper.GetFileString("Install.radWindowsAuthentication"), System.Security.Principal.WindowsIdentity.GetCurrent().Name);

        this.lblCorporateSite.Text = ResHelper.GetFileString("Install.radCorporateSite");
        this.lblCorporateSiteASPX.Text = ResHelper.GetFileString("Install.radCorporateSiteASPX");
        this.lblWizard.Text = ResHelper.GetFileString("Install.radWizard");
        this.lblExisting.Text = ResHelper.GetFileString("Install.radExisting");

        this.lblSQLServer.Text = ResHelper.GetFileString("Install.lblSQLServer");
        this.lblDatabase.Text = ResHelper.GetFileString("Install.lblDatabase");
        this.ltlScript.Text = ScriptHelper.GetScript("function NextStep(btnNext,elementDiv){btnNext.disabled=true;elementDiv.disabled=true;" + this.ClientScript.GetPostBackEventReference(btnHidden, null) + "}");
        mResult = "";

        // sets connection string panel
        string pass = System.Convert.ToString(ViewState["install.password"]) + "";
        lblConnectionString.Text = ResHelper.GetFileString("Install.lblConnectionString");

        wzdInstaller.StartNextButtonText = ResHelper.GetFileString("Install.NextStep");
        wzdInstaller.FinishCompleteButtonText = ResHelper.GetFileString("Install.Finish");
        wzdInstaller.FinishPreviousButtonText = ResHelper.GetFileString("Install.BackStep");
        wzdInstaller.StepNextButtonText = ResHelper.GetFileString("Install.NextStep");
        wzdInstaller.StepPreviousButtonText = ResHelper.GetFileString("Install.BackStep");
    }


    void btnPermissionContinue_Click(object sender, EventArgs e)
    {
        Response.Redirect(Request.Url.GetLeftPart(UriPartial.Path));
    }


    void btnPermissionSkip_Click(object sender, EventArgs e)
    {
        Response.Redirect(Request.Url.GetLeftPart(UriPartial.Path) + "?checkpermission=0");
    }


    void btnPermissionTest_Click(object sender, EventArgs e)
    {
        Response.Redirect(Request.Url.GetLeftPart(UriPartial.Path) + "?testagain=1");
    }


    protected void Page_PreRender(object sender, EventArgs e)
    {
        SetFields();
        // Display the log if result filled
        if (this.mDisplayLog)
        {
            this.txtLog.Text = mResult;
            this.pnlLog.Visible = true;
        }
        else
        {
            this.pnlLog.Visible = false;
        }
    }


    /// <summary>
    /// Appends the result string to the result message
    /// </summary>
    /// <param name="result">String to append</param>
    public void AddResult(string result)
    {
        mResult = result + "\n" + mResult;
    }


    public bool CreateDatabase()
    {
        try
        {
            AddResult(ResHelper.GetFileString("Installer.LogCreatingDatabase") + " " + this.txtNewDatabaseName.Text.Trim());

            string pass = System.Convert.ToString(ViewState["install.password"]) + "";
            string connectionString = InstallerFunctions.GetConnectionString(this.authenticationType, this.txtServerName.Text.Trim(), "", this.txtUsername.Text.Trim(), pass, 120, false);

            // Create the query
            string query = "CREATE DATABASE [" + this.txtNewDatabaseName.Text.Trim() + "] COLLATE SQL_Latin1_General_CP1_CI_AS";

            // Create the database
            IDataConnection conn = SqlHelperClass.GetConnection(connectionString);
            conn.AllowTransactions = false;
            conn.ExecuteQuery(query, null, QueryTypeEnum.SQLQuery);

            return true;
        }
        catch (Exception ex)
        {
            this.mDisplayLog = true;
            AddResult(ResHelper.GetFileString("Intaller.LogErrorCreateDB") + " " + ex.Message);
        }
        return false;
    }


    /// <summary>
    /// Performs the database installation
    /// </summary>
    /// <param name="connectionString">Connection string to the database</param>
    /// <param name="scriptsFolder">Folder with the database scripts</param>
    public bool InstallDatabase(string connectionString, string scriptsFolder)
    {
        IDataConnection conn = SqlHelperClass.GetConnection(connectionString);
        string applicationVirtualPath = CMSContext.WebApplicationVirtualPath;
        // *******************  SQL  *******************************
        string result = "";
        // create database objects 
        result = ProceedSQLScripts("defaultDBObjects.txt", conn, scriptsFolder, applicationVirtualPath);
        if (result != "")
        {
            this.mDisplayLog = true;
            AddResult(ResHelper.GetFileString("Installer.LogErrorCreateDBObjects") + " " + result);
            return false;
        }
        // insert default data
        result = ProceedSQLScripts(@"defaultData.txt", conn, scriptsFolder, applicationVirtualPath);
        if (result != "")
        {
            this.mDisplayLog = true;
            AddResult(ResHelper.GetFileString("Installer.LogErrorDefaultData") + " " + result);
            return false;
        }
        if (File.Exists(scriptsFolder + @"\webproject.txt"))
        {
            result = ProceedSQLScripts("webproject.txt", conn, scriptsFolder, applicationVirtualPath);
            if (result != "")
            {
                this.mDisplayLog = true;
                AddResult(ResHelper.GetFileString("Installer.LogErrorDefaultData") + " " + result);
                return false;
            }
        }
        return true;
    }


    /// <summary>
    /// Runs the SQL scripts listed in the given file
    /// </summary>
    /// <param name="fileName">FileName with the scripts to run</param>
    /// <param name="conn">SQL connection</param>
    /// <param name="scriptsFolder">Folder with the SQL scripts</param>
    /// <param name="virtDirName">Application virtual directory name</param>
    private string ProceedSQLScripts(string fileName, IDataConnection conn, string scriptsFolder, string virtDirName)
    {
        StreamReader str = null;
        string line = "";
        string scripts = "";
        string[] arrScripts = null;
        int i = 0;
        string query = "";

        // read all script names into scripts string
        str = File.OpenText(scriptsFolder + "\\" + fileName);
        while (str.Peek() > -1)
        {
            line = str.ReadLine();
            if (line.Trim() != "")
            {
                scripts += line + ";";
            }
        }
        if (scripts.Trim() != "")
        {
            scripts = scripts.Substring(0, scripts.Length - 1);
        }
        if (scripts == null)
        {
            return null;
        }
        arrScripts = scripts.Split(';');
        str.Close();

        // Trim the virtual directory name
        virtDirName = virtDirName.TrimEnd('/');
        // execute SQL scripts
        for (i = arrScripts.GetLowerBound(0); i <= arrScripts.GetUpperBound(0); i++)
        {
            // write to log
            AddResult(ResHelper.GetFileString("Installer.LogExecutingScript") + " " + arrScripts[i]);
            // run query
            str = File.OpenText(scriptsFolder + @"\" + arrScripts[i]);
            query = str.ReadToEnd();
            str.Close();
            if (query != "")
            {
                // Get the script
                if (arrScripts[i].ToLower().Trim().EndsWith("_data.sql"))
                {
                    if (virtDirName + "" != "")
                    {
                        query = query.Replace("/KenticoCMS/files", virtDirName + "/files");
                        query = query.Replace("/CorporateSite/", virtDirName + "/");
                    }
                    else
                    {
                        query = query.Replace("/KenticoCMS/files", "/files");
                        query = query.Replace("/CorporateSite/", "/");
                    }
                }

                // Run the query
                try
                {
                    conn.ExecuteQuery(query, null, QueryTypeEnum.SQLQuery);
                }
                catch (Exception ex)
                {
                    return ex.Message;
                }
            }
        }

        return "";
    }


    private void SetFields()
    {
        this.txtPassword.Enabled = this.radSQLAuthentication.Checked;
        this.txtUsername.Enabled = this.radSQLAuthentication.Checked;
        this.txtExistingDatabaseName.Enabled = this.radUseExisting.Checked;
        if (this.radCreateNew.Checked)
        {
            this.chkCreateDatabaseObjects.Checked = true;
            this.chkCreateDatabaseObjects.Enabled = false;
        }
        else
        {
            this.chkCreateDatabaseObjects.Enabled = true;
        }
        this.txtNewDatabaseName.Enabled = this.radCreateNew.Checked;
    }


    protected void btnWebSite_onClick(object sender, EventArgs e)
    {
        if (!SettingsKeyProvider.UsingVirtualPathProvider)
        {
            FormsAuthentication.SetAuthCookie("administrator", false);
            Response.Redirect("~/cmssitemanager/default.aspx?section=administration");
        }
        else
        {
            Response.Redirect(ResolveUrl("~/default.aspx"));
        }
    }


    protected void btnHidden_onClick(object sender, EventArgs e)
    {
        StepIndex++;

        switch (wzdInstaller.ActiveStepIndex)
        {
            case 0:
                ViewState["install.password"] = this.txtPassword.Text.Trim();

                // Set the authentication type
                if (this.radWindowsAuthentication.Checked)
                {
                    this.authenticationType = SQLServerAuthenticationModeEnum.WindowsAuthentication;
                }
                else
                {
                    this.authenticationType = SQLServerAuthenticationModeEnum.SQLServerAuthentication;
                }

                // Check the server name
                if (this.txtServerName.Text.Trim() == "")
                {
                    HandleError(ResHelper.GetFileString("Install.ErrorServerEmpty"));
                }
                // Check if it is possible to connect to the database
                string res = InstallerFunctions.TestConnection(this.authenticationType, this.txtServerName.Text.Trim(), this.txtExistingDatabaseName.Text.Trim(), this.txtUsername.Text.Trim(), ViewState["install.password"].ToString());
                if ((res != null) && (res != ""))
                {
                    HandleError(res, "Install.ErrorSqlTroubleshoot", ResolveUrl("~/CMSMessages/SQLError.aspx"));
                }
                else
                {
                    wzdInstaller.ActiveStepIndex = 1;
                }
                break;
            case 1:
                // gets database name
                string database = "";

                if (radCreateNew.Checked)
                {
                    database = txtNewDatabaseName.Text.Trim();
                }
                else
                {
                    database = txtExistingDatabaseName.Text.Trim();
                }

                ConnectionString = InstallerFunctions.GetConnectionString(this.authenticationType, this.txtServerName.Text.Trim(), database, this.txtUsername.Text.Trim(), ViewState["install.password"].ToString(), 120, false);

                if (this.radUseExisting.Checked)
                {
                    // Use existing database
                    if (database == "")
                    {
                        HandleError(ResHelper.GetFileString("Install.ErrorDBNameEmpty"));
                        return;
                    }
                    else if (!InstallerFunctions.DatabaseExists(this.authenticationType, this.txtServerName.Text.Trim(), database, this.txtUsername.Text.Trim(), ViewState["install.password"].ToString()))
                    {
                        HandleError(string.Format(ResHelper.GetFileString("Install.ErrorDatabseDoesntExist"), database));
                        return;
                    }
                }
                else
                {
                    // Create a new database
                    if (!this.CreateDatabase())
                    {
                        HandleError(string.Format(ResHelper.GetFileString("Install.ErrorCreateDB"), this.txtNewDatabaseName.Text));
                        return;
                    }
                    else
                    {
                        this.txtExistingDatabaseName.Text = this.txtNewDatabaseName.Text;
                        this.radCreateNew.Checked = false;
                        this.radUseExisting.Checked = true;
                    }
                }

                // Run SQL script
                if (this.chkCreateDatabaseObjects.Checked)
                {
                    if (!this.InstallDatabase(ConnectionString, Server.MapPath("~/cmsinstall/SQL")))
                    {
                        HandleError(ResHelper.GetFileString("Install.ErrorSetupDB"));
                        return;
                    }
                }

                // Check the DB connection
                this.pnlLog.Visible = false;

                // Set connection string
                if (InstallerFunctions.SetConnectionString(Server.MapPath("~/web.config"), "CMSConnectionString", ConnectionString))
                {
                    SqlHelperClass.ConnectionString = ConnectionString;


                    // Add license keys
                    if (AddTrialLicenseKeys(ConnectionString))
                    {
                        if ((hostName != "localhost") && (hostName != "127.0.0.1"))
                        {
                            wzdInstaller.ActiveStepIndex = 3;
                        }
                        else
                        {
                            wzdInstaller.ActiveStepIndex = 4;
                        }
                    }
                    else
                    {
                        wzdInstaller.ActiveStepIndex = 3;
                        ucLicenseDialog.SetLicenseExpired();
                    }
                }
                else
                {
                    string connStringDisplay = InstallerFunctions.GetConnectionString(this.authenticationType, this.txtServerName.Text.Trim(), database, this.txtUsername.Text.Trim(), ViewState["install.password"].ToString(), 120, true);
                    wzdInstaller.ActiveStepIndex = 2;
                    string message = ResHelper.GetFileString("Install.ConnectionStringError") + " <br/><br/><b>&lt;add name=\"CMSConnectionString\" connectionString=\"" + connStringDisplay + "\"/&gt;</b><br/><br/>";
                    lblErrorConnMessage.Text = message;

                    // Show troubleshoot link
                    this.lnkTroubleshoot.Visible = true;
                    this.lnkTroubleshoot.Target = "_blank";
                    this.lnkTroubleshoot.Text = ResHelper.GetFileString("Install.ErrorPermissions");
                    this.lnkTroubleshoot.NavigateUrl = ResolveUrl("~/CMSMessages/DiskPermissions.aspx");
                }
                break;

            // After connection string save error
            case 2:
                // if connectionstrings don't match
                if ((ConfigurationManager.ConnectionStrings["CMSConnectionString"] == null) ||
                   (ConfigurationManager.ConnectionStrings["CMSConnectionString"].ConnectionString == null) ||
                   (ConfigurationManager.ConnectionStrings["CMSConnectionString"].ConnectionString.Trim() == "") ||
                   (ConfigurationManager.ConnectionStrings["CMSConnectionString"].ConnectionString != ConnectionString))
                {
                    HandleError(ResHelper.GetFileString("Install.ErrorAddConnString"));
                    return;
                }
                else
                {
                    // Add license keys
                    if (AddTrialLicenseKeys(ConnectionString))
                    {
                        if ((hostName != "localhost") && (hostName != "127.0.0.1"))
                        {
                            wzdInstaller.ActiveStepIndex = 3;
                        }
                        else
                        {
                            wzdInstaller.ActiveStepIndex = 4;
                        }
                    }
                    else
                    {
                        wzdInstaller.ActiveStepIndex = 3;
                        ucLicenseDialog.SetLicenseExpired();
                    }
                }
                break;

            // After license entering
            case 3:
                try
                {
                    ucLicenseDialog.SetLicenseKey();
                    wzdInstaller.ActiveStepIndex = 4;
                }
                catch (Exception ex)
                {
                    HandleError(ex.Message);
                    return;
                }
                break;

            case 4:


                // Create CorporateSite
                if (radCorporateSite.Checked)
                {
                    SiteImportSettings settings = new SiteImportSettings();
                    settings.NewSiteName = "CorporateSite";
                    settings.NewSiteDisplayName = "Corporate Site";
                    if (HttpContext.Current != null)
                    {
                        string www = "www.";
                        if (hostName.StartsWith(www))
                        {
                            hostName = hostName.Remove(0, www.Length);
                        }

                        if (!HttpContext.Current.Request.Url.IsDefaultPort)
                        {
                            hostName += ":" + HttpContext.Current.Request.Url.Port;
                        }

                        settings.NewSiteDomain = hostName;
                        Domain = hostName;
                    }
                    settings.SourceFilePath = Path.Combine(settings.WebsitePath, ImportProvider.TEMPLATES_PATH + "\\" + ImportProvider.TEMPLATE_CORPORATE);
                    settings.IsPartOfInstallation = true;
                    settings.IsWebTemplate = true;

                    // Import the site
                    ImportTemplate(settings);
                }
                else if (radCorporateSiteASPX.Checked)
                {
                    SiteImportSettings settings = new SiteImportSettings();
                    settings.NewSiteName = "CorporateSiteASPX";
                    settings.NewSiteDisplayName = "Corporate Site ASPX";
                    if (HttpContext.Current != null)
                    {
                        string www = "www.";
                        if (hostName.StartsWith(www))
                        {
                            hostName = hostName.Remove(0, www.Length);
                        }

                        if (!HttpContext.Current.Request.Url.IsDefaultPort)
                        {
                            hostName += ":" + HttpContext.Current.Request.Url.Port;
                        }

                        settings.NewSiteDomain = hostName;
                        Domain = hostName;
                    }
                    settings.SourceFilePath = Path.Combine(settings.WebsitePath, ImportProvider.TEMPLATES_PATH + "\\" + ImportProvider.TEMPLATE_CORPORATEASPX);
                    settings.IsPartOfInstallation = true;
                    settings.IsWebTemplate = true;

                    // Import the site
                    ImportTemplate(settings);
                }
                // Else redirect to the site import
                else if (radExisting.Checked)
                {
                    FormsAuthentication.SetAuthCookie("administrator", false);
                    Response.Redirect("~/cmssitemanager/default.aspx?section=sites&action=import");
                }
                // Else redirect to the new site wizard
                else
                {
                    FormsAuthentication.SetAuthCookie("administrator", false);
                    Response.Redirect("~/cmssitemanager/default.aspx?section=sites&action=new");
                }
                break;
        }
        this.lblHeader.Text = string.Format(ResHelper.GetFileString("Install.DBHeaderStep"), StepIndex);
    }


    protected void wzdInstaller_PreviousButtonClick(object sender, WizardNavigationEventArgs e)
    {
        --StepIndex;
        this.lblHeader.Text = string.Format(ResHelper.GetFileString("Install.DBHeaderStep"), StepIndex);
    }


    private bool AddTrialLicenseKeys(string connectionString)
    {
        string licenseKey = ValidationHelper.GetString(ConfigurationManager.AppSettings["CMSTrialKey"], "");
        if (licenseKey != "")
        {
            IDataConnection conn = SqlHelperClass.GetConnection(connectionString);

            // Delete all existing license keys
            string query = "DELETE FROM CMS_LicenseKey";
            conn.ExecuteQuery(query, null, QueryTypeEnum.SQLQuery);

            //// License key for 'localhost' and '127.0.0.1' domain
            LicenseKeyInfo licenseInfo = new LicenseKeyInfo(licenseKey, "localhost");

            if (licenseInfo.ValidationResult != LicenseValidationEnum.Expired)
            {
                query = "INSERT INTO CMS_LicenseKey (LicenseDomain, LicenseKey, LicenseEdition, LicenseExpiration) VALUES ('localhost', '" + licenseKey + "','" + licenseInfo.EditionToChar() + "','" + licenseInfo.ExpirationDate.ToShortDateString() + "')";
                conn.ExecuteQuery(query, null, QueryTypeEnum.SQLQuery);

                licenseInfo = new LicenseKeyInfo(licenseKey, "127.0.0.1");
                query = "INSERT INTO CMS_LicenseKey (LicenseDomain, LicenseKey, LicenseEdition, LicenseExpiration) VALUES ('127.0.0.1', '" + licenseKey + "','" + licenseInfo.EditionToChar() + "','" + licenseInfo.ExpirationDate.ToShortDateString() + "')";
                conn.ExecuteQuery(query, null, QueryTypeEnum.SQLQuery);
            }
            else
            {
                return false;
            }
        }
        else
        {
            lblError.Text = ResHelper.GetFileString("Install.ErrorTrialLicense");
        }
        return true;
    }


    protected void HandleError(string message, WizardNavigationEventArgs e)
    {
        --StepIndex;
        this.lblError.Text = message;
        e.Cancel = true;
    }


    protected void HandleError(string message)
    {
        --StepIndex;
        this.lblError.Text = message;
        this.lblHeader.Text = string.Format(ResHelper.GetFileString("Install.DBHeaderStep"), StepIndex);
    }


    protected void HandleError(string message, string resourceString, string url)
    {
        --StepIndex;
        this.lblError.Text = message;
        this.lblHeader.Text = string.Format(ResHelper.GetFileString("Install.DBHeaderStep"), StepIndex);
        this.lnkTroubleshoot.Visible = true;
        this.lnkTroubleshoot.Target = "_blank";
        this.lnkTroubleshoot.Text = ResHelper.GetFileString(resourceString);
        this.lnkTroubleshoot.NavigateUrl = url;
    }


    // Import template
    private void ImportTemplate(SiteImportSettings settings)
    {
        // Try to import web template
        try
        {
            ImportProvider.ImportSite(settings);
            
            // Clear hashtables
            Functions.ClearHashtables();

            SiteInfoProvider.RunSite(settings.NewSiteName);

            ImportProvider.DeleteTemporaryFiles(settings, false);

            // Set current user default culture of the site
            CMSContext.CurrentUser.PreferredCultureCode = SettingsKeyProvider.GetStringValue(settings.NewSiteName + ".CMSDefaultCultureCode");

            // Check medium trust
            if (!SettingsKeyProvider.UsingVirtualPathProvider)
            {

                this.btnWebSite.Text = ResHelper.GetFileString("Install.lnkMediumTrust");
                this.lblMediumTrustInfo.Visible = true;
            }
            else
            {
                this.btnWebSite.Text = ResHelper.GetFileString("Install.lnkWebsite");
            }


            wzdInstaller.ActiveStepIndex = 5;
        }
        catch (Exception ex)
        {
            wzdInstaller.ActiveStepIndex = 4;
            lblError.Text = string.Format(ResHelper.GetFileString("Install.DetailError"), ex.Message, ex.StackTrace);

            try
            {
                ImportProvider.DeleteTemporaryFiles(settings, true);
            }
            catch
            {
            }
            return;
        }
    }
}

