-- Upgrade sql script from version 2.3 to 2.3a


/*  Views  */

IF EXISTS (SELECT * FROM sysobjects WHERE xtype = 'V' AND name = N'View_Node_Document') 
BEGIN
DROP VIEW View_Node_Document
END
GO

CREATE VIEW View_Node_Document
AS
SELECT     CMS_Tree.NodeID, CMS_Document.DocumentID, CMS_Tree.NodeSiteID, CMS_Tree.NodeClassID
FROM         CMS_Tree INNER JOIN
                      CMS_Document ON CMS_Document.DocumentNodeID = CMS_Tree.NodeID
WHERE     (CMS_Tree.NodeLinkedNodeID IS NULL)
UNION
SELECT     CMS_Tree_Linked.NodeID, CMS_Document_Linked.DocumentID, CMS_Tree_Linked.NodeSiteID, CMS_Tree_Linked.NodeClassID
FROM         CMS_Tree AS CMS_Tree_Linked INNER JOIN
                      CMS_Document AS CMS_Document_Linked ON CMS_Document_Linked.DocumentNodeID = CMS_Tree_Linked.NodeLinkedNodeID
WHERE     (CMS_Tree_Linked.NodeLinkedNodeID IS NOT NULL)
GO


DROP VIEW View_CMS_Tree_Joined
GO

CREATE VIEW View_CMS_Tree_Joined
AS
SELECT     CASE WHEN ((DocumentCheckedOutVersionHistoryID IS NULL AND DocumentPublishedVersionHistoryID IS NULL) OR
                      (DocumentCheckedOutVersionHistoryID IS NOT NULL AND DocumentPublishedVersionHistoryID IS NOT NULL)) AND (DocumentPublishFrom IS NULL OR
                      (DocumentPublishFrom IS NOT NULL AND DocumentPublishFrom <= getdate())) AND (DocumentPublishTo IS NULL OR
                      (DocumentPublishTo IS NOT NULL AND DocumentPublishTo >= getdate())) AND ((StepName <> 'archived') OR
                      (StepName IS NULL)) THEN 1 ELSE 0 END AS Published, CMS_Site.SiteName, CMS_Class.ClassName, CMS_Class.ClassDisplayName, 
                      CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentModifiedWhen, CMS_Document.DocumentModifiedByUserID, CMS_Document.DocumentForeignKeyValue, 
                      CMS_Document.DocumentCreatedByUserID, CMS_Document.DocumentCreatedWhen, CMS_Document.DocumentCheckedOutByUserID, 
                      CMS_Document.DocumentCheckedOutWhen, CMS_Document.DocumentCheckedOutVersionHistoryID, 
                      CMS_Document.DocumentPublishedVersionHistoryID, CMS_Document.DocumentWorkflowStepID, CMS_Document.DocumentPublishFrom, 
                      CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, CMS_Document.DocumentCulture, 
                      CMS_Document.DocumentNodeID, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentShowInSiteMap, 
                      CMS_Document.DocumentMenuItemHideInNavigation, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentMenuStyle, 
                      CMS_Document.DocumentMenuItemImage, CMS_Document.DocumentMenuItemLeftImage, 
                      CMS_Document.DocumentMenuItemRightImage, CMS_Document.DocumentPageTemplateID, CMS_Document.DocumentMenuJavascript, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_Document.DocumentUseNamePathForUrlPath, CMS_Document.DocumentStylesheetID, 
                      CMS_Document.DocumentContent, CMS_Tree.IsSecuredNode, CMS_Document.DocumentMenuClass, 
                      CMS_Document.DocumentMenuStyleOver, CMS_Document.DocumentMenuClassOver, CMS_Document.DocumentMenuItemImageOver, 
                      CMS_Document.DocumentMenuItemLeftImageOver, CMS_Document.DocumentMenuItemRightImageOver, 
                      CMS_Document.DocumentMenuStyleHighlighted, CMS_Document.DocumentMenuClassHighlighted, 
                      CMS_Document.DocumentMenuItemImageHighlighted, CMS_Document.DocumentMenuItemLeftImageHighlighted, 
                      CMS_Document.DocumentMenuItemRightImageHighlighted, CMS_Tree.NodeCacheMinutes, CMS_Tree.NodeSKUID, 
                      CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, COM_SKU.SKUID, COM_SKU.SKUNumber, COM_SKU.SKUName, 
                      COM_SKU.SKUDescription, COM_SKU.SKUPrice, COM_SKU.SKUEnabled, COM_SKU.SKUDepartmentID, COM_SKU.SKUManufacturerID, 
                      COM_SKU.SKUInternalStatusID, COM_SKU.SKUPublicStatusID, COM_SKU.SKUSupplierID, COM_SKU.SKUAvailableInDays, COM_SKU.SKUGUID, 
                      CMS_Tree.NodeInheritPageLevels, CMS_Document.DocumentMenuItemInactive, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Tree.NodeCustomData, CMS_Document.DocumentCustomData
FROM         View_Node_Document INNER JOIN
                      CMS_Document ON View_Node_Document.DocumentID = CMS_Document.DocumentID INNER JOIN
                      CMS_Tree ON CMS_Tree.NodeID = View_Node_Document.NodeID INNER JOIN
                      CMS_Site ON View_Node_Document.NodeSiteID = CMS_Site.SiteID INNER JOIN
                      CMS_Class ON View_Node_Document.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID = CMS_WorkflowStep.StepID LEFT OUTER JOIN
                      View_COM_SKU AS COM_SKU ON CMS_Tree.NodeSKUID = COM_SKU.SKUID
GO

DROP VIEW View_CMS_Tree_Joined_Versions
GO

CREATE VIEW View_CMS_Tree_Joined_Versions
AS
SELECT     CASE WHEN ((DocumentCheckedOutVersionHistoryID IS NULL AND DocumentPublishedVersionHistoryID IS NULL) OR
                      (DocumentCheckedOutVersionHistoryID IS NOT NULL AND DocumentPublishedVersionHistoryID IS NOT NULL)) AND (DocumentPublishFrom IS NULL OR
                      (DocumentPublishFrom IS NOT NULL AND DocumentPublishFrom <= getdate())) AND (DocumentPublishTo IS NULL OR
                      (DocumentPublishTo IS NOT NULL AND DocumentPublishTo >= getdate())) AND ((StepName <> 'archived') OR
                      (StepName IS NULL)) THEN 1 ELSE 0 END AS Published, CMS_Site.SiteName, CMS_Class.ClassName, CMS_Class.ClassDisplayName, 
                      CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentModifiedWhen, CMS_Document.DocumentModifiedByUserID, CMS_Document.DocumentForeignKeyValue, 
                      CMS_Document.DocumentCreatedByUserID, CMS_Document.DocumentCreatedWhen, CMS_Document.DocumentCheckedOutByUserID, 
                      CMS_Document.DocumentCheckedOutWhen, CMS_Document.DocumentCheckedOutVersionHistoryID, 
                      CMS_Document.DocumentPublishedVersionHistoryID, CMS_Document.DocumentWorkflowStepID, CMS_Document.DocumentPublishFrom, 
                      CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, CMS_Document.DocumentCulture, 
                      CMS_Document.DocumentNodeID, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentShowInSiteMap, 
                      CMS_Document.DocumentMenuItemHideInNavigation, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentMenuStyle, 
                      CMS_Document.DocumentMenuItemImage, CMS_Document.DocumentMenuItemLeftImage, 
                      CMS_Document.DocumentMenuItemRightImage, CMS_Document.DocumentPageTemplateID, CMS_Document.DocumentMenuJavascript, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_Document.DocumentUseNamePathForUrlPath, CMS_Document.DocumentStylesheetID, 
                      CMS_Document.DocumentContent, CMS_VersionHistory.NodeXML, CMS_Tree.IsSecuredNode, CMS_Document.DocumentMenuClass, 
                      CMS_Document.DocumentMenuStyleOver, CMS_Document.DocumentMenuClassOver, CMS_Document.DocumentMenuItemImageOver, 
                      CMS_Document.DocumentMenuItemLeftImageOver, CMS_Document.DocumentMenuItemRightImageOver, 
                      CMS_Document.DocumentMenuStyleHighlighted, CMS_Document.DocumentMenuClassHighlighted, 
                      CMS_Document.DocumentMenuItemImageHighlighted, CMS_Document.DocumentMenuItemLeftImageHighlighted, 
                      CMS_Document.DocumentMenuItemRightImageHighlighted, CMS_Tree.NodeCacheMinutes, CMS_Tree.NodeSKUID, 
                      CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, COM_SKU.SKUID, COM_SKU.SKUNumber, COM_SKU.SKUName, 
                      COM_SKU.SKUDescription, COM_SKU.SKUPrice, COM_SKU.SKUEnabled, COM_SKU.SKUDepartmentID, COM_SKU.SKUManufacturerID, 
                      COM_SKU.SKUInternalStatusID, COM_SKU.SKUPublicStatusID, COM_SKU.SKUSupplierID, COM_SKU.SKUAvailableInDays, COM_SKU.SKUGUID, 
                      CMS_Tree.NodeInheritPageLevels, CMS_Document.DocumentMenuItemInactive, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Tree.NodeCustomData, CMS_Document.DocumentCustomData
FROM         View_Node_Document INNER JOIN
                      CMS_Document ON View_Node_Document.DocumentID = CMS_Document.DocumentID INNER JOIN
                      CMS_Tree ON CMS_Tree.NodeID = View_Node_Document.NodeID INNER JOIN
                      CMS_Site ON View_Node_Document.NodeSiteID = CMS_Site.SiteID INNER JOIN
                      CMS_Class ON View_Node_Document.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_VersionHistory ON 
                      CMS_Document.DocumentCheckedOutVersionHistoryID = CMS_VersionHistory.VersionHistoryID LEFT OUTER JOIN
                      CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID = CMS_WorkflowStep.StepID LEFT OUTER JOIN
                      View_COM_SKU AS COM_SKU ON CMS_Tree.NodeSKUID = COM_SKU.SKUID
GO

DROP VIEW View_PageInfo
GO

CREATE VIEW  View_PageInfo
AS
SELECT     CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentPublishFrom, CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, 
                      CMS_Document.DocumentCulture, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentPageTemplateID, 
                      CMS_PageTemplate.PageTemplateID, CMS_PageTemplate.PageTemplateDisplayName, CMS_PageTemplate.PageTemplateDescription, 
                      CMS_PageTemplate.PageTemplateFile, CMS_PageTemplate.PageTemplateIsPortal, CMS_PageTemplate.PageTemplateCategoryID, 
                      CMS_PageTemplate.PageTemplateLayoutID, CMS_PageTemplate.PageTemplateWebParts, 
                      CMS_PageTemplate.PageTemplateIsReusable, CMS_Class.ClassName, CMS_Document.DocumentContent, 
                      CMS_PageTemplate.PageTemplateCodeName, CMS_Document.DocumentStylesheetID, CMS_Tree.IsSecuredNode, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_PageTemplate.PageTemplateInheritPageLevels, 
                      CMS_PageTemplate.PageTemplateShowAsMasterTemplate, CMS_Document.DocumentMenuJavascript, CMS_Tree.NodeCacheMinutes, 
                      CMS_Tree.NodeSKUID, CMS_Tree.NodeSKUID AS Expr1, CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, 
                      CMS_Tree.NodeInheritPageLevels, CMS_PageTemplate.PageTemplateLayout, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutFileName, CMS_PageTemplate.PageTemplateLayoutCheckedOutByUserID, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutMachineName, CMS_Document.DocumentMenuItemInactive, 
                      CMS_Document.DocumentMenuStyle, CMS_Document.DocumentMenuItemHideInNavigation, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Document.DocumentMenuClass
FROM         View_Node_Document INNER JOIN
                      CMS_Document ON View_Node_Document.DocumentID = CMS_Document.DocumentID INNER JOIN
                      CMS_Tree ON CMS_Tree.NodeID = View_Node_Document.NodeID INNER JOIN
                      CMS_Class ON View_Node_Document.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_PageTemplate ON CMS_Document.DocumentPageTemplateID = CMS_PageTemplate.PageTemplateID
GO

/*  DATA    */

/*update*/

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.document')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT ##TOPN## * FROM View_CMS_Tree_Joined_Versions WHERE ##WHERE## ORDER BY ##ORDERBY##' WHERE QueryName = 'SelectVersions' AND ClassID = @classid
END
GO


/*insert*/

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.tree')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectpageinfonoorder', 0, 'SELECT * FROM View_PageInfo WHERE (##WHERE##)', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.document')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectlisting', 0, 'SELECT ##TOPN## Published, NodeID, NodeParentID, NodeClassID, NodeLinkedNodeID, DocumentName, DocumentCulture, DocumentModifiedWhen, ClassDisplayName  FROM View_CMS_Tree_Joined WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selecttree', 0, 'SELECT ##TOPN## NodeID, NodeAliasPath, NodeName, NodeParentID, NodeClassID, NodeLevel, NodeChildNodesCount, NodeLinkedNodeID, DocumentName, DocumentCulture, DocumentModifiedWhen, ClassName  FROM View_CMS_Tree_Joined WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selecttreeversions', 0, 'SELECT ##TOPN## NodeID, NodeAliasPath, NodeName, NodeParentID, NodeClassID, NodeLevel, NodeChildNodesCount, NodeLinkedNodeID, DocumentName, DocumentCulture, DocumentModifiedWhen, ClassName, NodeXML  FROM View_CMS_Tree_Joined_Versions WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO



/* Add Connections between Payment and Shipping for all the objects */
/* Declare the selection table */
DECLARE @paymentTable TABLE (
	PaymentOptionID int
);

DECLARE @shippingTable TABLE (
	ShippingOptionID int
);

/* Get the payment list */
INSERT INTO @paymentTable SELECT PaymentOptionID FROM COM_PaymentOption;

/* Get the shipping list */
INSERT INTO @shippingTable SELECT ShippingOptionID FROM COM_ShippingOption;

/* Declare the cursor to loop through the table */
DECLARE @paymentCursor CURSOR;
SET @paymentCursor = CURSOR FOR SELECT PaymentOptionID FROM @paymentTable;

DECLARE @currentPaymentId int;

DECLARE @existingId int;


/* Loop through the table */
OPEN @paymentCursor
FETCH NEXT FROM @paymentCursor INTO @currentPaymentId;
WHILE @@FETCH_STATUS = 0
BEGIN
	/* Declare the cursor to loop through the table */
	DECLARE @shippingCursor CURSOR;
	SET @shippingCursor = CURSOR FOR SELECT ShippingOptionID FROM @shippingTable;

	DECLARE @currentShippingId int;

	OPEN @shippingCursor
	FETCH NEXT FROM @shippingCursor INTO @currentShippingId;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @existingId = 0;
		SET @existingId = (SELECT PaymentOptionID FROM COM_PaymentShipping WHERE PaymentOptionID = @currentPaymentId AND ShippingOptionID = @currentShippingId);

		IF @existingId IS NULL
		BEGIN
			INSERT INTO COM_PaymentShipping (PaymentOptionID, ShippingOptionID) VALUES (@currentPaymentId, @currentShippingId);
		END

		/* Get next record */
		FETCH NEXT FROM @shippingCursor INTO @currentShippingId;
	END

	CLOSE @shippingCursor;
	DEALLOCATE @shippingCursor;

	/* Get next record */
	FETCH NEXT FROM @paymentCursor INTO @currentPaymentId;
END

CLOSE @paymentCursor;
DEALLOCATE @paymentCursor;
